#   -*- coding: utf-8 -*-
#  SPDX-License-Identifier: MPL-2.0
#  Copyright 2020-2021 John Mille <john@compose-x.io>

""" Package used to store up JSON Schemas specifications for ComposeX"""

__author__ = """John Preston"""
__email__ = "john@compose-x.io"
__version__ = "0.2.3"
